@@ -481,6 +481,11 @@ print_status_query (const char *loc,
 		    const notmuch_query_t *query,
 		    notmuch_status_t status);
 
+notmuch_status_t
+print_status_message (const char *loc,
+		      const notmuch_message_t *message,
+		      notmuch_status_t status);
+
 notmuch_status_t
 print_status_database (const char *loc,
 		       const notmuch_database_t *database,
